@@ -58,7 +58,7 @@ get_backend_info_for_mime_type (const gchar *mime_type)
                 guint i;
 
                 for (i = 0; mime_types[i] != NULL; ++i) {
-                        if (g_content_type_is_mime_type (mime_type, mime_types[i]))
+                        if (g_ascii_strcasecmp (mime_type, mime_types[i]) == 0)
                                 return info;
                 }
         }
@@ -317,7 +317,8 @@ ev_document_factory_get_document_full (const char           *uri,
 
 		if (result == FALSE || err) {
 			if (err &&
-			    g_error_matches (err, EV_DOCUMENT_ERROR, EV_DOCUMENT_ERROR_ENCRYPTED)) {
+			    (g_error_matches (err, EV_DOCUMENT_ERROR, EV_DOCUMENT_ERROR_ENCRYPTED) ||
+			     g_error_matches (err, EV_DOCUMENT_ERROR, EV_DOCUMENT_ERROR_UNSUPPORTED_CONTENT))) {
 				g_propagate_error (error, err);
 				return document;
 			    }
